from django.utils.translation import gettext_lazy
from wagtail.admin.wagtail_hooks import hooks
from wagtail.admin.panels import set_default_page_edit_handlers, ObjectList, TabbedInterface
from wagtail.utils.decorators import cached_classmethod

from wagtail_admin_preview.panels import AdminPreviewPanel


@cached_classmethod
def get_edit_handler(cls):
	"""
	Get the panel to use in the Wagtail admin when editing this page type.
	:param cls:
	:return:
	"""

	if hasattr(cls, "edit_handler"):
		edit_handler = cls.edit_handler
	else:
		# construct a TabbedInterface made up of content_panels, promote_panels
		# and settings_panels, skipping any which are empty
		tabs = []
		if cls.content_panels:
			tabs.append(ObjectList(cls.content_panels, heading=gettext_lazy("Content")))
		if cls.preview_panels:
			tabs.append(
				ObjectList(
					cls.preview_panels,
					heading=gettext_lazy("Preview"),
					classname="preview",
				)
			)
			edit_handler = TabbedInterface(tabs, base_form_class=cls.base_form_class)
		if cls.promote_panels:
			tabs.append(ObjectList(cls.promote_panels, heading=gettext_lazy("Promote")))
		if cls.settings_panels:
			tabs.append(
				ObjectList(
					cls.settings_panels,heading=gettext_lazy("Settings"),classname="settings",
				)
			)
	return edit_handler.bind_to_model(cls)


def add_preview_panel(cls):
	"""
	Add the preview panel to the default set of panels in wagtail page editor
	:param cls:
	:return:
	"""
	set_default_page_edit_handlers(cls)
	cls.preview_panels = [
		AdminPreviewPanel('Live Preview', classname='full')
	]


@hooks.register("register_icons")
def register_icons(icons):
    return icons + [
		 'wagtailadmin/icons/mobile-screen.svg',
		 'wagtailadmin/icons/tablet-screen.svg',
		 'wagtailadmin/icons/desktop-screen.svg'
	 ]


from django.conf import settings
from django.template.loader import get_template
from wagtail.admin.panels import Panel


class AdminPreviewPanel(Panel):
	class BoundPanel(Panel.BoundPanel):
		template_name = 'wagtail_admin_preview/preview_panel.html'
		rendered = None

		def __init__(self, *args, **kwargs):
			super(AdminPreviewPanel.BoundPanel, self).__init__(*args, **kwargs)

		def render_html(self, parent_context=None):
			preview_instance = self.instance.serve_preview(self.request, 'admin_preview')
			template = get_template(preview_instance.template_name)
			self.rendered = template.render(preview_instance.context_data).replace('\n', '')
			panel = get_template(self.template_name)
			if parent_context is None:
				parent_context = {}

			try:
				sizes = settings.__getattr__('WAGTAIL_ADMIN_PREVIEW_BREAKPOINTS')
			except AttributeError:
				sizes = [375, 766, 1278]

			parent_context.update(
				{'self': self, 'sizes': sizes}
			)
			return panel.render(parent_context)



from django.apps import AppConfig


class WagtailAdminPreviewAppConfig(AppConfig):

	name='wagtail_admin_preview'

	def ready(self):
		from wagtail.models import Page
		from wagtail_admin_preview import wagtail_hooks

		wagtail_hooks.add_preview_panel(Page)
		Page.get_edit_handler = wagtail_hooks.get_edit_handler
